######################################################################
package HM3Data;
######################################################################

=head1 NAME

HM3Data -- data from 3rd edition HarnMaster as Perl data structures

=head1 DESCRIPTION

This is a basic set of 
  @skilldefs       = an array of hash references with the skill data
  %occupationhash  = a hash of hash references with occupation skills
  %occupationroll  = a hash of hash references with roll for occupation

=cut

require 5.003;
use strict;
use Carp;

######################################################################
my @skilldefs = 
    ({"name"=>"Acrobatics","type"=>"Physical","sb"=>"STR AGL AGL","signs"=>"Nad+2;Hir+1","oml"=>"SB2"},
     {"name"=>"Climbing","type"=>"Physical","sb"=>"STR DEX AGL","signs"=>"Ula/Ara+2","oml"=>"SB4"},
     {"name"=>"Condition","type"=>"Physical","sb"=>"STR STA WIL","signs"=>"Ula/Lad+1","oml"=>"SB5"},
     {"name"=>"Dancing","type"=>"Physical","sb"=>"DEX AGL AGL","signs"=>"Tar+2;Hir/Tai+1","oml"=>"SB2"},
     {"name"=>"Jumping","type"=>"Physical","sb"=>"STR AGL AGL","signs"=>"Nad/Hir+2","oml"=>"SB4"},
     {"name"=>"Legerdemain","type"=>"Physical","sb"=>"DEX DEX WIL","signs"=>"Sko/Tai/Tar+2","oml"=>"SB1"},
     {"name"=>"Skiing","type"=>"Physical","sb"=>"STR DEX AGL","signs"=>"Mas+2;Sko/Lad+1","oml"=>"SB1"},
     {"name"=>"Stealth","type"=>"Physical","sb"=>"AGL HRG WIL","signs"=>"Hir/Tar/Tai+2","oml"=>"SB3"},
     {"name"=>"Swimming","type"=>"Physical","sb"=>"STA DEX AGL","signs"=>"Sko+1;Mas/Lad+3","oml"=>"SB1"},
     {"name"=>"Throwing","type"=>"Physical","sb"=>"STR DEX EYE","signs"=>"Hir+2;Tar/Nad+1","oml"=>"SB4"},
     {"name"=>"Acting","type"=>"Communication","sb"=>"AGL VOI INT","signs"=>"Tar/Tai+1","oml"=>"SB2"},
     {"name"=>"Awareness","type"=>"Communication","sb"=>"EYE HRG SML","signs"=>"Hir/Tar+2","oml"=>"SB4"},
     {"name"=>"Intrigue","type"=>"Communication","sb"=>"INT AUR WIL","signs"=>"Tai/Tar/Sko+1","oml"=>"SB3"},
     {"name"=>"Lovecraft","type"=>"Communication","sb"=>"CML AGL VOI","signs"=>"Mas/Ang+1","oml"=>"SB3"},
     {"name"=>"Mental Conflict","type"=>"Communication","sb"=>"AUR WIL WIL","signs"=>"none","oml"=>"SB3"},
     {"name"=>"Oratory","type"=>"Communication","sb"=>"CML VOI INT","signs"=>"Tar+1","oml"=>"SB2"},
     {"name"=>"Rhetoric","type"=>"Communication","sb"=>"VOI INT WIL","signs"=>"Tai/Tar/Sko+1","oml"=>"SB3"},
     {"name"=>"Singing","type"=>"Communication","sb"=>"HRG VOI VOI","signs"=>"Mas+1","oml"=>"SB3"},
     {"name"=>"Musician","type"=>"Communication","sb"=>"DEX HRG HRG","signs"=>"Mas/Ang+1","oml"=>"SB1"},
     {"name"=>"Musician: First","type"=>"Communication","sb"=>"DEX HRG HRG","signs"=>"Mas/Ang+1","oml"=>"SB1"},
     {"name"=>"Musician: Second","type"=>"Communication","sb"=>"DEX HRG HRG","signs"=>"Mas/Ang+1","oml"=>"SB1"},
     {"name"=>"Musician: Third","type"=>"Communication","sb"=>"DEX HRG HRG","signs"=>"Mas/Ang+1","oml"=>"SB1"},
     {"name"=>"Musician: Drum","type"=>"Communication","sb"=>"DEX HRG HRG","signs"=>"Mas/Ang+1","oml"=>"SB1"},
     {"name"=>"Musician: Flute","type"=>"Communication","sb"=>"DEX HRG HRG","signs"=>"Mas/Ang+1","oml"=>"SB1"},
     {"name"=>"Musician: Harp","type"=>"Communication","sb"=>"DEX HRG HRG","signs"=>"Mas/Ang+1","oml"=>"SB1"},
     {"name"=>"Musician: Horn","type"=>"Communication","sb"=>"DEX HRG HRG","signs"=>"Mas/Ang+1","oml"=>"SB1"},
     {"name"=>"Musician: Pipes","type"=>"Communication","sb"=>"DEX HRG HRG","signs"=>"Mas/Ang+1","oml"=>"SB1"},
     {"name"=>"Musician: Lute","type"=>"Communication","sb"=>"DEX HRG HRG","signs"=>"Mas/Ang+1","oml"=>"SB1"},
     {"name"=>"Musician: Other","type"=>"Communication","sb"=>"DEX HRG HRG","signs"=>"Mas/Ang+1","oml"=>"SB1"},
     {"name"=>"Language: Native","type"=>"Language","sb"=>"VOI INT WIL","signs"=>"Tai+1","oml"=>"SB1"},
     {"name"=>"Language: Second","type"=>"Language","sb"=>"VOI INT WIL","signs"=>"Tai+1","oml"=>"SB1"},
     {"name"=>"Language: Third","type"=>"Language","sb"=>"VOI INT WIL","signs"=>"Tai+1","oml"=>"SB1"},
     {"name"=>"Language: Altish","type"=>"Language","sb"=>"VOI INT WIL","signs"=>"Tai+1","oml"=>"SB1"},
     {"name"=>"Language: Azeri","type"=>"Language","sb"=>"VOI INT WIL","signs"=>"Tai+1","oml"=>"SB1"},
     {"name"=>"Language: Azeryani","type"=>"Language","sb"=>"VOI INT WIL","signs"=>"Tai+1","oml"=>"SB1"},
     {"name"=>"Language: Besha","type"=>"Language","sb"=>"VOI INT WIL","signs"=>"Tai+1","oml"=>"SB1"},
     {"name"=>"Language: Byrian","type"=>"Language","sb"=>"VOI INT WIL","signs"=>"Tai+1","oml"=>"SB1"},
     {"name"=>"Language: Emela","type"=>"Language","sb"=>"VOI INT WIL","signs"=>"Tai+1","oml"=>"SB1"},
     {"name"=>"Language: Harbaalese","type"=>"Language","sb"=>"VOI INT WIL","signs"=>"Tai+1","oml"=>"SB1"},
     {"name"=>"Language: Harnic","type"=>"Language","sb"=>"VOI INT WIL","signs"=>"Tai+1","oml"=>"SB1"},
     {"name"=>"Language: High Azeryani","type"=>"Language","sb"=>"VOI INT WIL","signs"=>"Tai+1","oml"=>"SB1"},
     {"name"=>"Language: Ivashi","type"=>"Language","sb"=>"VOI INT WIL","signs"=>"Tai+1","oml"=>"SB1"},
     {"name"=>"Language: Ivinian","type"=>"Language","sb"=>"VOI INT WIL","signs"=>"Tai+1","oml"=>"SB1"},
     {"name"=>"Language: Jarinese","type"=>"Language","sb"=>"VOI INT WIL","signs"=>"Tai+1","oml"=>"SB1"},
     {"name"=>"Language: Karejian","type"=>"Language","sb"=>"VOI INT WIL","signs"=>"Tai+1","oml"=>"SB1"},
     {"name"=>"Language: Karuia","type"=>"Language","sb"=>"VOI INT WIL","signs"=>"Tai+1","oml"=>"SB1"},
     {"name"=>"Language: Khuzdul","type"=>"Language","sb"=>"VOI INT WIL","signs"=>"Tai+1","oml"=>"SB1"},
     {"name"=>"Language: Low Azeryani","type"=>"Language","sb"=>"VOI INT WIL","signs"=>"Tai+1","oml"=>"SB1"},
     {"name"=>"Language: Old Jarinese","type"=>"Language","sb"=>"VOI INT WIL","signs"=>"Tai+1","oml"=>"SB1"},
     {"name"=>"Language: Orbaalese","type"=>"Language","sb"=>"VOI INT WIL","signs"=>"Tai+1","oml"=>"SB1"},
     {"name"=>"Language: Ormauk","type"=>"Language","sb"=>"VOI INT WIL","signs"=>"Tai+1","oml"=>"SB1"},
     {"name"=>"Language: Palithanian","type"=>"Language","sb"=>"VOI INT WIL","signs"=>"Tai+1","oml"=>"SB1"},
     {"name"=>"Language: Quarph","type"=>"Language","sb"=>"VOI INT WIL","signs"=>"Tai+1","oml"=>"SB1"},
     {"name"=>"Language: Shorka","type"=>"Language","sb"=>"VOI INT WIL","signs"=>"Tai+1","oml"=>"SB1"},
     {"name"=>"Language: Sindarin","type"=>"Language","sb"=>"VOI INT WIL","signs"=>"Tai+1","oml"=>"SB1"},
     {"name"=>"Language: Surikal","type"=>"Language","sb"=>"VOI INT WIL","signs"=>"Tai+1","oml"=>"SB1"},
     {"name"=>"Language: Trierzi","type"=>"Language","sb"=>"VOI INT WIL","signs"=>"Tai+1","oml"=>"SB1"},
     {"name"=>"Language: Urmech","type"=>"Language","sb"=>"VOI INT WIL","signs"=>"Tai+1","oml"=>"SB1"},
     {"name"=>"Language: Yarili","type"=>"Language","sb"=>"VOI INT WIL","signs"=>"Tai+1","oml"=>"SB1"},
     {"name"=>"Language: Kamaki","type"=>"Language","sb"=>"VOI INT WIL","signs"=>"Tai+1","oml"=>"SB1"},
     {"name"=>"Language: Solori","type"=>"Language","sb"=>"VOI INT WIL","signs"=>"Tai+1","oml"=>"SB1"},
     {"name"=>"Language: Other","type"=>"Language","sb"=>"VOI INT WIL","signs"=>"Tai+1","oml"=>"SB1"},
     {"name"=>"Script: Native","type"=>"Script","sb"=>"DEX EYE INT","signs"=>"Tar/Tai+1","oml"=>"70+SB1"},
     {"name"=>"Script: Second","type"=>"Script","sb"=>"DEX EYE INT","signs"=>"Tar/Tai+1","oml"=>"70+SB1"},
     {"name"=>"Script: Third","type"=>"Script","sb"=>"DEX EYE INT","signs"=>"Tar/Tai+1","oml"=>"70+SB1"},
     {"name"=>"Script: AntaIrdic","type"=>"Script","sb"=>"DEX EYE INT","signs"=>"Tar/Tai+1","oml"=>"70+SB1"},
     {"name"=>"Script: AntaKyri","type"=>"Script","sb"=>"DEX EYE INT","signs"=>"Tar/Tai+1","oml"=>"70+SB1"},
     {"name"=>"Script: Ayaran","type"=>"Script","sb"=>"DEX EYE INT","signs"=>"Tar/Tai+1","oml"=>"70+SB1"},
     {"name"=>"Script: Chanorian","type"=>"Script","sb"=>"DEX EYE INT","signs"=>"Tar/Tai+1","oml"=>"70+SB1"},
     {"name"=>"Script: Khruni","type"=>"Script","sb"=>"DEX EYE INT","signs"=>"Tar/Tai+1","oml"=>"70+SB1"},
     {"name"=>"Script: Korotanish","type"=>"Script","sb"=>"DEX EYE INT","signs"=>"Tar/Tai+1","oml"=>"70+SB1"},
     {"name"=>"Script: Lakise","type"=>"Script","sb"=>"DEX EYE INT","signs"=>"Tar/Tai+1","oml"=>"70+SB1"},
     {"name"=>"Script: Mayesi","type"=>"Script","sb"=>"DEX EYE INT","signs"=>"Tar/Tai+1","oml"=>"70+SB1"},
     {"name"=>"Script: Neramic","type"=>"Script","sb"=>"DEX EYE INT","signs"=>"Tar/Tai+1","oml"=>"70+SB1"},
     {"name"=>"Script: Nuvesarl","type"=>"Script","sb"=>"DEX EYE INT","signs"=>"Tar/Tai+1","oml"=>"70+SB1"},
     {"name"=>"Script: Runic","type"=>"Script","sb"=>"DEX EYE INT","signs"=>"Tar/Tai+1","oml"=>"70+SB1"},
     {"name"=>"Script: Selenian","type"=>"Script","sb"=>"DEX EYE INT","signs"=>"Tar/Tai+1","oml"=>"70+SB1"},
     {"name"=>"Script: Tianta","type"=>"Script","sb"=>"DEX EYE INT","signs"=>"Tar/Tai+1","oml"=>"70+SB1"},
     {"name"=>"Script: Vastienish","type"=>"Script","sb"=>"DEX EYE INT","signs"=>"Tar/Tai+1","oml"=>"70+SB1"},
     {"name"=>"Script: Zerin","type"=>"Script","sb"=>"DEX EYE INT","signs"=>"Tar/Tai+1","oml"=>"70+SB1"},
     {"name"=>"Script: Other","type"=>"Script","sb"=>"DEX EYE INT","signs"=>"Tar/Tai+1","oml"=>"70+SB1"},
     {"name"=>"Ritual: Agrik","type"=>"Religion","sb"=>"VOI INT STR","signs"=>"Nad+2;Ang/Ahn+1","oml"=>"SB1"},
     {"name"=>"Ritual: Halea","type"=>"Religion","sb"=>"VOI INT CML","signs"=>"Tar+2;Hir/Mas+1","oml"=>"SB1"},
     {"name"=>"Ritual: Ilvir","type"=>"Religion","sb"=>"VOI INT AUR","signs"=>"Sko+2;Tai/Ula+1","oml"=>"SB1"},
     {"name"=>"Ritual: Larani","type"=>"Religion","sb"=>"VOI INT WIL","signs"=>"Ang+2;Ahn/Fen+1","oml"=>"SB1"},
     {"name"=>"Ritual: Morgath","type"=>"Religion","sb"=>"VOI INT AUR","signs"=>"Lad+2;Ahn/Mas+1","oml"=>"SB1"},
     {"name"=>"Ritual: Naveh","type"=>"Religion","sb"=>"VOI INT WIL","signs"=>"Mas+2;Sko/Tar+1","oml"=>"SB1"},
     {"name"=>"Ritual: Peoni","type"=>"Religion","sb"=>"VOI INT DEX","signs"=>"Ara+2;Ang/Ula+1","oml"=>"SB1"},
     {"name"=>"Ritual: Sarajin","type"=>"Religion","sb"=>"VOI INT STR","signs"=>"Fen+2;Ara/Lad+1","oml"=>"SB1"},
     {"name"=>"Ritual: Save-K'nor","type"=>"Religion","sb"=>"VOI INT INT","signs"=>"Tai+2;Sko/Tar+1","oml"=>"SB1"},
     {"name"=>"Ritual: Siem","type"=>"Religion","sb"=>"VOI INT AUR","signs"=>"Hir+2;Fen/Ula+1","oml"=>"SB1"},
     {"name"=>"Ritual: Tribal","type"=>"Religion","sb"=>"VOI INT VOI","signs"=>"Ula+2;Nad/Tar+1","oml"=>"SB1"},
     {"name"=>"Ritual: Adaenum","type"=>"Religion","sb"=>"VOI INT DEX","signs"=>"Lad+2;Hir/Sko+1","oml"=>"SB1"},
     {"name"=>"Ritual: Anoa","type"=>"Religion","sb"=>"VOI INT AUR","signs"=>"Sko+2;Tai/Ula+1","oml"=>"SB1"},
     {"name"=>"Ritual: Bujoc","type"=>"Religion","sb"=>"VOI INT AUR","signs"=>"","oml"=>"SB1"},
     {"name"=>"Ritual: Chelni","type"=>"Religion","sb"=>"VOI INT AUR","signs"=>"Ahn+2;Fen/Tai+1","oml"=>"SB1"},
     {"name"=>"Ritual: Chymak","type"=>"Religion","sb"=>"VOI INT DEX","signs"=>"Lad+2;Fen/Sko+1","oml"=>"SB1"},
     {"name"=>"Ritual: Equani","type"=>"Religion","sb"=>"VOI INT AUR","signs"=>"Ara+2;Ang/Fen+1","oml"=>"SB1"},
     {"name"=>"Ritual: Gozyda","type"=>"Religion","sb"=>"VOI INT WIL","signs"=>"Ahn+2;Tai/Tar+1","oml"=>"SB1"},
     {"name"=>"Ritual: Kabloqui","type"=>"Religion","sb"=>"VOI INT AUR","signs"=>"Ara+2;Ang/Fen+1","oml"=>"SB1"},
     {"name"=>"Ritual: Kamaki","type"=>"Religion","sb"=>"VOI INT DEX","signs"=>"Lad+2;Ahn/Ula+1","oml"=>"SB1"},
     {"name"=>"Ritual: Kath","type"=>"Religion","sb"=>"VOI INT AUR","signs"=>"Hir+2;Ahn/Ula+1","oml"=>"SB1"},
     {"name"=>"Ritual: Kubora","type"=>"Religion","sb"=>"VOI INT AUR","signs"=>"Ara+2;Ula/Tar+1","oml"=>"SB1"},
     {"name"=>"Ritual: Pagaelin","type"=>"Religion","sb"=>"VOI INT AUR","signs"=>"","oml"=>"SB1"},
     {"name"=>"Ritual: Solori","type"=>"Religion","sb"=>"VOI INT INT","signs"=>"Ang+2;Nad/Tai+1","oml"=>"SB1"},
     {"name"=>"Ritual: Taelda","type"=>"Religion","sb"=>"VOI INT AUR","signs"=>"Ula+2;Hir/Tai+1","oml"=>"SB1"},
     {"name"=>"Ritual: Tulwyn","type"=>"Religion","sb"=>"VOI INT STR","signs"=>"Hir+2;Ang/Sko+1","oml"=>"SB1"},
     {"name"=>"Ritual: Urdu","type"=>"Religion","sb"=>"VOI INT AUR","signs"=>"Ara+2;Mas/Tai+1","oml"=>"SB1"},
     {"name"=>"Ritual: Ymodi","type"=>"Religion","sb"=>"VOI INT AUR","signs"=>"","oml"=>"SB1"},
     {"name"=>"Initiative","type"=>"Combat","sb"=>"AGL WIL WIL","signs"=>"none","oml"=>"SB4"},
     {"name"=>"Unarmed","type"=>"Combat","sb"=>"STR DEX AGL","signs"=>"Mas/Lad/Ula+2","oml"=>"SB4"},
     {"name"=>"Riding","type"=>"Combat","sb"=>"DEX AGL WIL","signs"=>"Ula/Ara+1","oml"=>"SB1"},
     {"name"=>"Axe","type"=>"Combat","sb"=>"STR STR DEX","signs"=>"Ahn/Fen/Ang+1","oml"=>"SB3"},
     {"name"=>"Blowgun","type"=>"Combat","sb"=>"STA DEX EYE","signs"=>"Hir+2;Tar/Nad+1","oml"=>"SB4"},
     {"name"=>"Bow","type"=>"Combat","sb"=>"STR DEX EYE","signs"=>"Hir/Tar/Nad+1","oml"=>"SB2"},
     {"name"=>"Club","type"=>"Combat","sb"=>"STR STR DEX","signs"=>"Ula/Ara+1","oml"=>"SB4"},
     {"name"=>"Dagger","type"=>"Combat","sb"=>"DEX DEX EYE","signs"=>"Ang/Nad+2","oml"=>"SB3"},
     {"name"=>"Flail","type"=>"Combat","sb"=>"DEX DEX DEX","signs"=>"Hir/Tar/Nad+1","oml"=>"SB1"},
     {"name"=>"Net","type"=>"Combat","sb"=>"DEX DEX EYE","signs"=>"Mas/Sko/Lad+1","oml"=>"SB1"},
     {"name"=>"Polearm","type"=>"Combat","sb"=>"STR STR DEX","signs"=>"Ang/Ara+1","oml"=>"SB2"},
     {"name"=>"Shield","type"=>"Combat","sb"=>"STR DEX DEX","signs"=>"Ula/Lad/Mas+1","oml"=>"SB3"},
     {"name"=>"Sling","type"=>"Combat","sb"=>"DEX DEX EYE","signs"=>"Hir/Tar/Nad+1","oml"=>"SB1"},
     {"name"=>"Spear","type"=>"Combat","sb"=>"STR STR DEX","signs"=>"Ara/Fen/Ula+1","oml"=>"SB3"},
     {"name"=>"Sword","type"=>"Combat","sb"=>"STR DEX DEX","signs"=>"Ang+3;Ahn/Nad+1","oml"=>"SB3"},
     {"name"=>"Whip","type"=>"Combat","sb"=>"DEX DEX EYE","signs"=>"Hir/Nad+1","oml"=>"SB1"},
     {"name"=>"Agriculture","type"=>"Craft/Lore","sb"=>"STR STA WIL","signs"=>"Ula/Ara+2","oml"=>"SB2"},
     {"name"=>"Alchemy","type"=>"Craft/Lore","sb"=>"SML INT AUR","signs"=>"Sko+3;Tai/Mas+2","oml"=>"SB1"},
     {"name"=>"Animalcraft","type"=>"Craft/Lore","sb"=>"AGL VOI WIL","signs"=>"Ula/Ara+1","oml"=>"SB1"},
     {"name"=>"Astrology","type"=>"Craft/Lore","sb"=>"EYE INT AUR","signs"=>"Tar+1","oml"=>"SB1"},
     {"name"=>"Brewing","type"=>"Craft/Lore","sb"=>"DEX SML SML","signs"=>"Sko+3;Tai/Mas+2","oml"=>"SB2"},
     {"name"=>"Ceramics","type"=>"Craft/Lore","sb"=>"DEX DEX EYE","signs"=>"Ula/Ara+2","oml"=>"SB2"},
     {"name"=>"Cookery","type"=>"Craft/Lore","sb"=>"DEX SML SML","signs"=>"Sko+1","oml"=>"SB3"},
     {"name"=>"Drawing","type"=>"Craft/Lore","sb"=>"DEX EYE EYE","signs"=>"Sko/Tai+1","oml"=>"SB2"},
     {"name"=>"Embalming","type"=>"Craft/Lore","sb"=>"DEX EYE SML","signs"=>"Sko/Ula+1","oml"=>"SB1"},
     {"name"=>"Engineering","type"=>"Craft/Lore","sb"=>"DEX INT INT","signs"=>"Ula/Ara+2;Fen+1","oml"=>"SB1"},
     {"name"=>"Fishing","type"=>"Craft/Lore","sb"=>"DEX EYE WIL","signs"=>"Mas/Lad+2","oml"=>"SB3"},
     {"name"=>"Fletching","type"=>"Craft/Lore","sb"=>"DEX DEX EYE","signs"=>"Hir+2;Tar/Nad+1","oml"=>"SB1"},
     {"name"=>"Folklore","type"=>"Craft/Lore","sb"=>"VOI INT INT","signs"=>"Tai+2","oml"=>"SB3"},
     {"name"=>"Foraging","type"=>"Craft/Lore","sb"=>"DEX SML INT","signs"=>"Ula/Ara+2","oml"=>"SB3"},
     {"name"=>"Glasswork","type"=>"Craft/Lore","sb"=>"DEX EYE WIL","signs"=>"Fen+2","oml"=>"SB1"},
     {"name"=>"Heraldry","type"=>"Craft/Lore","sb"=>"DEX EYE WIL","signs"=>"Sko/Tai+1","oml"=>"SB1"},
     {"name"=>"Herblore","type"=>"Craft/Lore","sb"=>"EYE SML INT","signs"=>"Ula+3;Ara+2","oml"=>"SB1"},
     {"name"=>"Hidework","type"=>"Craft/Lore","sb"=>"DEX SML WIL","signs"=>"Ula/Ara+1","oml"=>"SB2"},
     {"name"=>"Jewelcraft","type"=>"Craft/Lore","sb"=>"DEX EYE WIL","signs"=>"Fen+3;Tar/Ara+1","oml"=>"SB1"},
     {"name"=>"Law","type"=>"Craft/Lore","sb"=>"VOI INT WIL","signs"=>"Tar/Tai+1","oml"=>"SB1"},
     {"name"=>"Lockcraft","type"=>"Craft/Lore","sb"=>"DEX EYE WIL","signs"=>"Fen+1","oml"=>"SB1"},
     {"name"=>"Masonry","type"=>"Craft/Lore","sb"=>"STR DEX INT","signs"=>"Ula/Ara+2","oml"=>"SB1"},
     {"name"=>"Mathematics","type"=>"Craft/Lore","sb"=>"INT INT WIL","signs"=>"Tai+3;Tar/Sko+1","oml"=>"SB1"},
     {"name"=>"Metalcraft","type"=>"Craft/Lore","sb"=>"STR DEX WIL","signs"=>"Fen+3;Ahn/Ang+1","oml"=>"SB1"},
     {"name"=>"Milling","type"=>"Craft/Lore","sb"=>"STR DEX SML","signs"=>"Ula+1","oml"=>"SB2"},
     {"name"=>"Mining","type"=>"Craft/Lore","sb"=>"STR EYE INT","signs"=>"Ula/Ara+2;Fen+1","oml"=>"SB1"},
     {"name"=>"Perfumery","type"=>"Craft/Lore","sb"=>"SML SML INT","signs"=>"Hir/Sko/Tar+1","oml"=>"SB1"},
     {"name"=>"Physician","type"=>"Craft/Lore","sb"=>"DEX EYE INT","signs"=>"Mas+2;Sko/Tai+1","oml"=>"SB1"},
     {"name"=>"Piloting","type"=>"Craft/Lore","sb"=>"DEX EYE INT","signs"=>"Lad+3;Mas+1","oml"=>"SB1"},
     {"name"=>"Runecraft","type"=>"Craft/Lore","sb"=>"INT AUR AUR","signs"=>"Tai+2;Sko+1","oml"=>"SB1"},
     {"name"=>"Seamanship","type"=>"Craft/Lore","sb"=>"STR DEX AGL","signs"=>"Lad+3;Mas/Sko+1","oml"=>"SB2"},
     {"name"=>"Shipwright","type"=>"Craft/Lore","sb"=>"STR DEX INT","signs"=>"Lad+3;Mas+1","oml"=>"SB1"},
     {"name"=>"Survival","type"=>"Craft/Lore","sb"=>"STR DEX INT","signs"=>"Ula+2;Ara+1","oml"=>""},
     {"name"=>"Tarotry","type"=>"Craft/Lore","sb"=>"INT AUR WIL","signs"=>"Tar/Tai+2;Sko/Hir+1","oml"=>"SB1"},
     {"name"=>"Textilecraft","type"=>"Craft/Lore","sb"=>"DEX DEX EYE","signs"=>"Ula/Ara+1","oml"=>"SB2"},
     {"name"=>"Timbercraft","type"=>"Craft/Lore","sb"=>"STR DEX AGL","signs"=>"Ula+3;Ara+1","oml"=>"SB2"},
     {"name"=>"Tracking","type"=>"Craft/Lore","sb"=>"EYE SML WIL","signs"=>"Ula/Ara+3","oml"=>"SB2"},
     {"name"=>"Weaponcraft","type"=>"Craft/Lore","sb"=>"STR DEX WIL","signs"=>"Fen+3;Ahn/Ang+1","oml"=>"SB1"},
     {"name"=>"Weatherlore","type"=>"Craft/Lore","sb"=>"INT EYE SML","signs"=>"Hir/Tar/Mas/Lad+1","oml"=>"SB3"},
     {"name"=>"Woodcraft","type"=>"Craft/Lore","sb"=>"DEX DEX WIL","signs"=>"Ula+2;Ara/Lad+1","oml"=>"SB2"},
     {"name"=>"Convocation: Neutral","type"=>"Convocation","sb"=>"AUR AUR WIL","signs"=>"none","oml"=>"SB1"},
     {"name"=>"Convocation: Lyahvi","type"=>"Convocation","sb"=>"AUR AUR EYE","signs"=>"Hir+3;Nad/Tar+2;Ang/Tai+1;Fen/Mas-1;Ara/Lad-2;Ula-3","oml"=>"SB2"},
     {"name"=>"Convocation: Peleahn","type"=>"Convocation","sb"=>"AUR AUR AGL","signs"=>"Agn+3;Ahn/Nad+2;Fen/Hir+1;Ula/Tai-1;Sko/Lad-2;Mas-3","oml"=>"SB2"},
     {"name"=>"Convocation: Jmorvi","type"=>"Convocation","sb"=>"AUR AUR STR","signs"=>"Fen+3;Ara/Ahn+2;Ula/Ang+1;Hir/Mas-1;Tar/Sko-2;Tai-3","oml"=>"SB2"},
     {"name"=>"Convocation: Fyvria","type"=>"Convocation","sb"=>"AUR AUR SML","signs"=>"Ula+3;Ara/Lad+2;Fen/Mas+1;Ang/Tai-1;Nad/Tar-2;Hir-3","oml"=>"SB2"},
     {"name"=>"Convocation: Odivshe","type"=>"Convocation","sb"=>"AUR AUR DEX","signs"=>"Mas+3;Sko/Lad+2;Ula/Tai+1;Fen/Hir-1;Ahn/Nad-2;Ang-3","oml"=>"SB2"},
     {"name"=>"Convocation: Savorya","type"=>"Convocation","sb"=>"AUR AUR INT","signs"=>"Tai+3;Tar/Sko+2;Hir/Mas+1;Ula/Ang-1;Ara/Ahn-2;Fen-3","oml"=>"SB2"},
     {"name"=>"Charm","type"=>"Talent","sb"=>"AUR AUR WIL","signs"=>"Tai/Nad/Tar+1","oml"=>"SB1"},
     {"name"=>"Clairvoyance","type"=>"Talent","sb"=>"AUR AUR WIL","signs"=>"Tai+1","oml"=>"SB1"},
     {"name"=>"Disembodiment","type"=>"Talent","sb"=>"AUR AUR WIL","signs"=>"Hir/Nad+1","oml"=>"SB1"},
     {"name"=>"Healing","type"=>"Talent","sb"=>"AUR AUR WIL","signs"=>"Mas/Sko+1","oml"=>"SB1"},
     {"name"=>"Hex","type"=>"Talent","sb"=>"AUR AUR WIL","signs"=>"Ahn+1","oml"=>"SB1"},
     {"name"=>"Medium","type"=>"Talent","sb"=>"AUR AUR WIL","signs"=>"Tai+1","oml"=>"SB1"},
     {"name"=>"Mental Bolt","type"=>"Talent","sb"=>"AUR AUR WIL","signs"=>"Ahn+1","oml"=>"SB1"},
     {"name"=>"Negation","type"=>"Talent","sb"=>"AUR AUR WIL","signs"=>"Fen+1","oml"=>"SB1"},
     {"name"=>"Prescience","type"=>"Talent","sb"=>"AUR AUR WIL","signs"=>"Tai/Tar+1","oml"=>"SB1"},
     {"name"=>"Psychometry","type"=>"Talent","sb"=>"AUR AUR WIL","signs"=>"Tai/Mas+1","oml"=>"SB1"},
     {"name"=>"Pyrokinesis","type"=>"Talent","sb"=>"AUR AUR WIL","signs"=>"Ang/Ahn/Nad+1","oml"=>"SB1"},
     {"name"=>"Sensitivity","type"=>"Talent","sb"=>"AUR AUR WIL","signs"=>"Tar/Tai+1","oml"=>"SB1"},
     {"name"=>"Telekinesis","type"=>"Talent","sb"=>"AUR AUR WIL","signs"=>"Nad/Ahn+1","oml"=>"SB1"},
     {"name"=>"Telepathy","type"=>"Talent","sb"=>"AUR AUR WIL","signs"=>"Tar/Tai/Sko+1","oml"=>"SB1"},
     {"name"=>"Transference","type"=>"Talent","sb"=>"AUR AUR WIL","signs"=>"Tar/Tai+1","oml"=>"SB1"},
     {"name"=>"Transmutation","type"=>"Talent","sb"=>"AUR AUR WIL","signs"=>"Tar/Tai+1","oml"=>"SB1"},
     {"name"=>"Unique Talent","type"=>"Talent","sb"=>"AUR AUR WIL","signs"=>"none","oml"=>"SB1"},
     );

######################################################################
### None is for error cases
my %occupationhash = 
    ("None"=>{"urban"=>0,"years"=>0
			},
     "Automatic"=>{"urban"=>0,"years"=>0,
			"Climbing"=>"SB4",
			"Condition"=>"SB5",
			"Jumping"=>"SB4",
			"Stealth"=>"SB3",
			"Throwing"=>"SB4",
			"Awareness"=>"SB4",
			"Intrigue"=>"SB3",
			"Oratory"=>"SB2",
			"Rhetoric"=>"SB3",
			"Singing"=>"SB3",
			"Language: Native"=>"50+SB1",
			"Initiative"=>"SB4",
			"Unarmed"=>"SB4",
			},
     "Optional"=>{"urban"=>0,"years"=>0,
			"Acrobatics"=>"SB2",
			"Acting"=>"SB2",
			"Agriculture"=>"SB2",
			"Animalcraft"=>"SB1",
			"Brewing"=>"SB2",
			"Ceramics"=>"SB2",
			"Cookery"=>"SB3",
			"Dancing"=>"SB2",
			"Drawing"=>"SB2",
			"Fishing"=>"SB3",
			"Folklore"=>"SB3",
			"Foraging"=>"SB3",
			"Hidework"=>"SB2",
			"Lovecraft"=>"SB3",
			"Musician: First"=>"SB1",
			"Survival"=>"SB3",
			"Swimming"=>"SB1",
			"Textilecraft"=>"SB2",
			"Timbercraft"=>"SB2",
			"Tracking"=>"SB2",
			"Weatherlore"=>"SB3",
			"Woodcraft"=>"SB2"
			},
     "Optional: Cleric"=>{"urban"=>0,"years"=>0,
			"Acting"=>"SB2",
			"Alchemy"=>"SB2",
			"Astrology"=>"SB2",
			"Cookery"=>"SB4",
			"Dagger"=>"SB4",
			"Dancing"=>"SB3",
			"Drawing"=>"SB3",
			"Embalming"=>"SB2",
			"Heraldry"=>"SB2",
			"Herblore"=>"SB2",
			"Hidework"=>"SB2",
			"Law"=>"SB2",
			"Mathematics"=>"SB2",
			"Musician: First"=>"SB2",
			"Physician"=>"SB2",
			"Riding"=>"SB2",
			"Runecraft"=>"SB2",
			"Skiing"=>"SB2",
			"Sling"=>"SB2",
			"Spear (Staff)"=>"SB4",
			"Survival"=>"SB3",
			"Swimming"=>"SB2",
			"Tarotry"=>"SB2",
			"Unarmed"=>"SB4",
			"Weatherlore"=>"SB3"
			},
     "Optional: Shek-Pvar"=>{"urban"=>0,"years"=>0,
			"Acting"=>"SB2",
			"Alchemy"=>"SB2",
			"Astrology"=>"SB2",
			"Cookery"=>"SB4",
			"Dancing"=>"SB3",
			"Dagger"=>"SB3",
			"Hidework"=>"SB2",
			"Mental Conflict"=>"SB4",
			"Musician: First"=>"SB2",
			"Riding"=>"SB2",
			"Runecraft"=>"SB2",
			"Skiing"=>"SB2",
			"Sling"=>"SB2",
			"Spear (Staff)"=>"SB4",
			"Survival"=>"SB3",
			"Swimming"=>"SB2",
			"Tarotry"=>"SB2",
			"Unarmed"=>"SB4",
			"Weatherlore"=>"SB3"
			},
     "Alchemist"=>{"urban"=>90,"years"=>7,
			"Alchemy"=>"SB4",
			"Mathematics"=>"SB3",
			"Herblore"=>"SB3",
			"Mining"=>"SB2",
			"Physician"=>"SB2",
			"Language: Native"=>"60+SB1",
			"Script: Native"=>"70+SB1"
			},
     "Animal Trainer"=>{"urban"=>75,"years"=>3,
			"Animalcraft"=>"SB4",
			"Hidework"=>"SB2",
			"Riding"=>"SB2"
			},
     "Apothecary"=>{"urban"=>90,"years"=>6,
			"Herblore"=>"SB4",
			"Alchemy"=>"SB2",
			"Mathematics"=>"SB2",
			"Physician"=>"SB2",
			"Language: Native"=>"60+SB1",
			"Script: Native"=>"70+SB1"
			},
     "Archer"=>{"urban"=>75,"years"=>4,
			"Initiative"=>"SB5",
			"Bow (Shortbow)"=>"SB5",
			"Sword (Shortsword)"=>"SB5",
			"Shield (Buckler)"=>"SB5",
			"Dagger"=>"SB5",
			"Foraging"=>"SB4",
			"Survival"=>"SB4",
			"Heraldry"=>"SB2",
			"Physician"=>"SB2",
			"Fletching"=>"SB2"
			},
     "Astrologer"=>{"urban"=>90,"years"=>4,
			"Astrology"=>"SB4",
			"Drawing"=>"SB3",
			"Language: Native"=>"60+SB1",
			"Script: Native"=>"70+SB1",
			"Mathematics"=>"SB3",
			"Tarotry"=>"SB2"
			},
     "Bailiff"=>{"urban"=>0,"years"=>7,
			"Riding"=>"SB6",
			"Initiative"=>"SB6",
			"Polearm (Lance)"=>"SB6",
			"Sword (Broadsword)"=>"SB5",
			"Axe (Handaxe)"=>"SB5",
			"Dagger (Dagger)"=>"SB5",
			"Shield (Knight)"=>"SB6",
			"Dancing"=>"SB3",
			"Law"=>"SB3",
			"Agriculture"=>"SB2",
			"Foraging"=>"SB4",
			"Survival"=>"SB4",
			"Heraldry"=>"SB2",
			"Physician"=>"SB2",
			"Weaponcraft"=>"SB2"
			},
     "Beggar"=>{"urban"=>95,"years"=>1,
			"Rhetoric"=>"SB5",
			"Intrigue"=>"SB4",
			"Dagger"=>"SB4"
			},
     "Cartographer/Artist"=>{"urban"=>90,"years"=>5,
			"Drawing"=>"SB4",
			"Mathematics"=>"SB2",
			"Language: Native"=>"60+SB1",
			"Script: Native"=>"70+SB1"
			},
     "Chandler"=>{"urban"=>95,"years"=>4,
			"Hidework"=>"SB3",
			"Textilecraft"=>"SB3",
			"Woodcraft"=>"SB3",
			"Alchemy"=>"SB2",
			"Metalcraft"=>"SB2",
			"Script: Native"=>"70+SB1",
			"Language: Native"=>"60+SB1"
			},
     "Charcoaler"=>{"urban"=>10,"years"=>3,
			"Timbercraft"=>"SB3",
			"Survival"=>"SB3",
			"Woodcraft"=>"SB2",
			"Metalcraft"=>"SB2",
			"Language: Native"=>"60+SB1"
			},
     "Chieftain"=>{"urban"=>0,"years"=>7,
			"Initiative"=>"SB6",
			"Intrigue"=>"SB4",
			"Tracking"=>"SB4",
			"Spear"=>"SB4",
			"Shield"=>"SB4",
			"Bow"=>"SB3",
			"Foraging"=>"SB3",
			"Survival"=>"SB3",
			"Law"=>"SB2",
			"Hidework"=>"SB2",
			"Fletching"=>"SB2"
			},
     "Clansman"=>{"urban"=>70,"years"=>4,
			"Initiative"=>"SB5",
			"Spear"=>"SB6",
			"Shield (Round)"=>"SB6",
			"Bow (Shortbow)"=>"SB5",
			"Dagger (Keltan)"=>"SB5",
			"Seamanship"=>"SB3",
			"Foraging"=>"SB4",
			"Survival"=>"SB4",
			"Heraldry"=>"SB2",
			"Physician"=>"SB2",
			"Weaponcraft"=>"SB2"
			},
     "Cleric"=>{"urban"=>65,"years"=>6,
			"Rhetoric"=>"SB4",
			"Intrigue"=>"SB4",
			"Mental Conflict"=>"SB4",
			"Oratory"=>"SB3",
			"Folklore"=>"SB3",
			"Embalming"=>"SB2",
			"Physician"=>"SB2",
			"Law"=>"SB2",
			"Drawing"=>"SB2",
			"Heraldry"=>"SB2",
			"Language: Native"=>"70+SB1",
			"Script: Native"=>"70+SB1"
			},
     "Package:Cleric:Agrik"=>{"urban"=>65,"years"=>6,
			"Ritual: Agrik"=>"SB4",
			"Initiative"=>"SB6",
			"Unarmed"=>"SB4",
			"Axe (Sickle)"=>"SB4",
			"Club (Mace)"=>"SB4",
			"Shield"=>"SB4",
			"Heraldry"=>"SB3",
			"Language: Azeryani"=>"SB3",
			"Script: Zerin"=>"70+SB1",
			"Language: Surikal"=>"SB3"
			},
     "Package:Cleric:Halea"=>{"urban"=>85,"years"=>6,
			"Ritual: Halea"=>"SB4",
			"Lovecraft"=>"SB4",
			"Dancing"=>"SB3",
			"Mathematics"=>"SB2",
			"Musician: First"=>"SB2",
			"Perfumery"=>"SB2",
			"Language: Second"=>"SB4",
			"Script: Second"=>"70+SB1",
			"Language: Karuia"=>"SB3",
			"Script: Zerin"=>"70+SB1"
			},
     "Package:Cleric:Ilvir"=>{"urban"=>65,"years"=>6,
			"Ritual: Ilvir"=>"SB4",
			"Animalcraft (Ivashu)"=>"SB4",
			"Drawing"=>"SB3",
			"Physician"=>"SB3",
			"Tarotry"=>"SB2",
			"Herblore"=>"SB2",
			"Language: Old Jarinese"=>"SB3",
			"Language: Ivashi"=>"SB3",
			"Script: Khruni"=>"70+SB1"
			},
     "Package:Cleric:Larani"=>{"urban"=>65,"years"=>6,
			"Ritual: Larani"=>"SB4",
			"Initiative"=>"SB6",
			"Unarmed"=>"SB4",
			"Dagger"=>"SB4",
			"Sword"=>"SB4",
			"Shield"=>"SB4",
			"Heraldry"=>"SB3",
			"Language: Emela"=>"SB3",
			"Script: Khruni"=>"70+SB1"
			},
     "Package:Cleric:Morgath"=>{"urban"=>65,"years"=>6,
			"Ritual: Morgath"=>"SB4",
			"Dagger"=>"SB4",
			"Embalming"=>"SB3",
			"Hidework (Human Skin)"=>"SB2",
			"Woodcraft (Masks)"=>"SB2",
			"Tarotry"=>"SB2",
			"Language: Azeri"=>"SB3",
			"Language: Ormauk"=>"SB3",
			"Script: Nuvesarl"=>"70+SB1"
			},
     "Package:Cleric:Naveh"=>{"urban"=>65,"years"=>6,
			"Ritual: Naveh"=>"SB4",
			"Initiative"=>"SB6",
			"Unarmed"=>"SB5",
			"Stealth"=>"SB5",
			"Dagger"=>"SB4",
			"Acrobatics"=>"SB3",
			"Legerdemain"=>"SB2",
			"Lockcraft"=>"SB2",
			"Language: Besha"=>"SB3",
			"Script: Neramic"=>"70+SB1"
			},
     "Package:Cleric:Peoni"=>{"urban"=>45,"years"=>6,
			"Ritual: Peoni"=>"SB4",
			"Agriculture"=>"SB4",
			"Animalcraft"=>"SB3",
			"Herblore"=>"SB3",
			"Physician"=>"SB3",
			"Weatherlore"=>"SB3",
			"Textilecraft"=>"SB2",
			"Language: Emela"=>"SB3",
			"Script: Khruni"=>"70+SB1"
			},
     "Package:Cleric:Sarajin"=>{"urban"=>65,"years"=>6,
			"Ritual: Sarajin"=>"SB4",
			"Initiative"=>"SB6",
			"Unarmed"=>"SB4",
			"Axe"=>"SB4",
			"Dagger"=>"SB4",
			"Shield"=>"SB4",
			"Runecraft"=>"SB3",
			"Seamanship"=>"SB2",
			"Language: Ivinian"=>"SB3",
			"Script: Runic"=>"70+SB1"
			},
     "Package:Cleric:Save-K'nor"=>{"urban"=>85,"years"=>7,
			"Ritual: Save-K'nor"=>"SB4",
			"Drawing"=>"SB3",
			"Mathematics"=>"SB3",
			"Law"=>"SB3",
			"Heraldry"=>"SB2",
			"Language: Azeri"=>"SB3",
			"Script: Tianta"=>"70+SB1",
			"Language: Second"=>"SB4",
			"Language: Third"=>"SB3",
			"Script: Second"=>"70+SB1"
			},
     "Package:Cleric:Siem"=>{"urban"=>45,"years"=>6,
			"Ritual: Siem"=>"SB4",
			"Astrology"=>"SB4",
			"Runecraft"=>"SB3",
			"Foraging"=>"SB3",
			"Survival"=>"SB3",
			"Weatherlore"=>"SB3",
			"Tarotry"=>"SB2",
			"Musician: First"=>"SB2",
			"Herblore"=>"SB2",
			"Language: Sindarin"=>"SB3",
			"Script: Selenian"=>"70+SB1"
			},
     "Clothier"=>{"urban"=>95,"years"=>6,
			"Textilecraft"=>"SB4",
			"Hidework"=>"SB3",
			"Jewelcraft"=>"SB3",
			"Language: Native"=>"60+SB1",
			"Script: Native"=>"70+SB1"
			},
     "Cook/Servant"=>{"urban"=>0,"years"=>3,
			"Intrigue"=>"SB4",
			"Rhetoric"=>"SB4",
			"Cookery"=>"SB4",
			"Textilecraft"=>"SB3",
			"Herblore"=>"SB2"
			},
     "Courtesan"=>{"urban"=>99,"years"=>3,
			"Lovecraft"=>"SB5",
			"Intrigue"=>"SB5",
			"Singing"=>"SB5",
			"Musician: First"=>"SB3",
			"Dancing"=>"SB3",
			"Language: Native"=>"60+SB1",
			"Script: Native"=>"70+SB1"
			},
     "Embalmer"=>{"urban"=>95,"years"=>7,
			"Embalming"=>"SB4",
			"Woodcraft"=>"SB2",
			"Alchemy"=>"SB2",
			"Perfumery"=>"SB2",
			"Language: Native"=>"60+SB1",
			"Script: Native"=>"70+SB1"
			},
     "Farmer"=>{"urban"=>0,"years"=>4,
			"Agriculture"=>"SB4",
			"Weatherlore"=>"SB4",
			"Animalcraft"=>"SB3"
			},
     "Fisherman"=>{"urban"=>50,"years"=>5,
			"Fishing"=>"SB5",
			"Seamanship"=>"SB4",
			"Weatherlore"=>"SB4",
			"Piloting"=>"SB2",
			"Shipwright"=>"SB2"
			},
     "Gladiator"=>{"urban"=>95,"years"=>4,
			"Initiative"=>"SB6",
			"Sword"=>"SB5",
			"Shield"=>"SB5",
			"Net"=>"SB3",
			"Unarmed"=>"SB5",
			"Physician"=>"SB2"
			},
     "Glassworker"=>{"urban"=>90,"years"=>7,
			"Glasswork"=>"SB4",
			"Ceramics"=>"SB2",
			"Alchemy"=>"SB2",
			"Language: Native"=>"60+SB1",
			"Script: Native"=>"70+SB1"
			},
     "Guardian"=>{"urban"=>70,"years"=>5,
			"Initiative"=>"SB5",
			"Spear"=>"SB7",
			"Sword (Longknife)"=>"SB6",
			"Dagger (Dagger)"=>"SB5",
			"Shield (Round)"=>"SB6",
			"Foraging"=>"SB4",
			"Survival"=>"SB4",
			"Heraldry"=>"SB2",
			"Physician"=>"SB2",
			"Weaponcraft"=>"SB2"
			},
     "Guardsman"=>{"urban"=>90,"years"=>4,
			"Initiative"=>"SB5",
			"Spear"=>"SB6",
			"Sword (Shortsword)"=>"SB6",
			"Dagger (Dagger)"=>"SB5",
			"Shield (Round)"=>"SB5",
			"Foraging"=>"SB4",
			"Survival"=>"SB4",
			"Heraldry"=>"SB2",
			"Physician"=>"SB2",
			"Weaponcraft"=>"SB2"
			},
     "Harper/Skald"=>{"urban"=>80,"years"=>7,
			"Singing"=>"SB5",
			"Folklore"=>"SB4",
			"Oratory"=>"SB4",
			"Musician: First"=>"SB4",
			"Musician: Second"=>"SB3",
			"Musician: Third"=>"SB3",
			"Woodcraft"=>"SB3",
			"Language: Native"=>"60+SB1",
			"Script: Native"=>"70+SB1"
			},
     "Herald"=>{"urban"=>80,"years"=>5,
			"Heraldry"=>"SB4",
			"Oratory"=>"SB4",
			"Rhetoric"=>"SB4",
			"Intrigue"=>"SB5",
			"Drawing"=>"SB4",
			"Riding"=>"SB1",
			"Initiative"=>"SB4",
			"Polearm (Lance)"=>"SB2",
			"Sword (Broadsword)"=>"SB3",
			"Axe (Handaxe)"=>"SB3",
			"Dagger"=>"SB3",
			"Shield (Knight)"=>"SB3",
			"Dancing"=>"SB2",
			"Script: Native"=>"70+SB1",
			"Language: Native"=>"70+SB1",
			"Language: Second"=>"70+SB1"
			},
     "Herdsman"=>{"urban"=>0,"years"=>2,
			"Animalcraft"=>"SB4",
			"Tracking"=>"SB3",
			"Survival"=>"SB3",
			"Weatherlore"=>"SB4"
			},
     "Hideworker"=>{"urban"=>40,"years"=>5,
			"Hidework"=>"SB4",
			"Textilecraft"=>"SB2",
			"Alchemy"=>"SB2",
			"Language: Native"=>"60+SB1"
			},
     "High Guard"=>{"urban"=>70,"years"=>5,
			"Initiative"=>"SB6",
			"Polearm (Poleaxe)"=>"SB6",
			"Club (Mace)"=>"SB5",
			"Dagger (Dagger)"=>"SB5",
			"Shield (Round)"=>"SB5",
			"Foraging"=>"SB4",
			"Survival"=>"SB4",
			"Heraldry"=>"SB2",
			"Physician"=>"SB2",
			"Weaponcraft"=>"SB2"
			},
     "Horsebow"=>{"urban"=>25,"years"=>4,
			"Initiative"=>"SB5",
			"Riding"=>"SB6",
			"Bow (Hartbow)"=>"SB6",
			"Polearm (Lance)"=>"SB5",
			"Sword (Longknife)"=>"SB5",
			"Shield (Knight)"=>"SB6",
			"Foraging"=>"SB4",
			"Survival"=>"SB4",
			"Heraldry"=>"SB2",
			"Physician"=>"SB2",
			"Weaponcraft"=>"SB2",
			"Dancing"=>"SB3",
			"Musician: First"=>"SB2"
			},
     "Hunter/Trapper"=>{"urban"=>10,"years"=>5,
			"Tracking"=>"SB4",
			"Spear"=>"SB4",
			"Bow"=>"SB3",
			"Dagger"=>"SB4",
			"Foraging"=>"SB3",
			"Survival"=>"SB3",
			"Hidework"=>"SB2",
			"Fletching"=>"SB2"
			},
     "Huscarl"=>{"urban"=>70,"years"=>5,
			"Axe (Battleaxe)"=>"SB6",
			"Initiative"=>"SB6",
			"Sword (Broadsword)"=>"SB5",
			"Dagger (Keltan)"=>"SB5",
			"Shield (Round)"=>"SB5",
			"Seamanship"=>"SB3",
			"Piloting"=>"SB2",
			"Foraging"=>"SB4",
			"Survival"=>"SB4",
			"Heraldry"=>"SB2",
			"Physician"=>"SB2",
			"Weaponcraft"=>"SB2"
			},
     "Innkeeper"=>{"urban"=>35,"years"=>5,
			"Brewing"=>"SB4",
			"Cookery"=>"SB4",
			"Rhetoric"=>"SB4",
			"Intrigue"=>"SB4",
			"Language: Native"=>"60+SB1",
			"Language: Second"=>"60+SB1",
			"Script: Native"=>"70+SB1"
			},
     "Jeweler"=>{"urban"=>99,"years"=>7,
			"Jewelcraft"=>"SB4",
			"Metalcraft"=>"SB3",
			"Mining"=>"SB2",
			"Language: Native"=>"60+SB1",
			"Script: Native"=>"70+SB1"
			},
     "Knight"=>{"urban"=>0,"years"=>7,
			"Riding"=>"SB6",
			"Initiative"=>"SB6",
			"Polearm (Lance)"=>"SB6",
			"Sword (Broadsword)"=>"SB5",
			"Axe (Handaxe)"=>"SB5",
			"Dagger (Dagger)"=>"SB5",
			"Shield (Knight)"=>"SB6",
			"Dancing"=>"SB3",
			"Law"=>"SB3",
			"Agriculture"=>"SB2",
			"Foraging"=>"SB4",
			"Survival"=>"SB4",
			"Heraldry"=>"SB2",
			"Physician"=>"SB2",
			"Weaponcraft"=>"SB2"
			},
     "Knight Bachelor"=>{"urban"=>50,"years"=>7,
			"Riding"=>"SB6",
			"Initiative"=>"SB6",
			"Polearm (Lance)"=>"SB6",
			"Sword (Broadsword)"=>"SB5",
			"Axe (Handaxe)"=>"SB5",
			"Dagger (Dagger)"=>"SB5",
			"Shield (Knight)"=>"SB6",
			"Dancing"=>"SB3",
			"Foraging"=>"SB4",
			"Survival"=>"SB4",
			"Heraldry"=>"SB2",
			"Physician"=>"SB2",
			"Weaponcraft"=>"SB2"
			},
     "Lady"=>{"urban"=>40,"years"=>7,
			"Intrigue"=>"SB5",
			"Folklore"=>"SB4",
			"Textilecraft (Needlework)"=>"SB3",
			"Dancing"=>"SB3",
			"Heraldry"=>"SB3",
			"Astrology"=>"SB2",
			"Drawing"=>"SB2"
			},
     "Legionnaire"=>{"urban"=>90,"years"=>4,
			"Initiative"=>"SB5",
			"Spear"=>"SB6",
			"Sword (Shortsowrd)"=>"SB5",
			"Dagger (Dagger)"=>"SB4",
			"Shield (Tower)"=>"SB5",
			"Foraging"=>"SB4",
			"Survival"=>"SB4",
			"Heraldry"=>"SB2",
			"Physician"=>"SB2",
			"Weaponcraft"=>"SB2"
			},
     "Lexigrapher"=>{"urban"=>95,"years"=>5,
			"Hidework (Parchment)"=>"SB4",
			"Alchemy (Inkcraft)"=>"SB4",
			"Drawing"=>"SB3",
			"Language: Native"=>"60+SB1",
			"Script: Native"=>"70+SB1",
			"Script: Second"=>"70+SB1"
			},
     "Litigant"=>{"urban"=>95,"years"=>7,
			"Law"=>"SB4",
			"Oratory"=>"SB5",
			"Rhetoric"=>"SB5",
			"Intrigue"=>"SB5",
			"Language: Native"=>"60+SB1",
			"Language: Second"=>"60+SB1",
			"Script: Native"=>"70+SB1"
			},
     "Locksmith"=>{"urban"=>95,"years"=>6,
			"Lockcraft"=>"SB4",
			"Metalcraft"=>"SB3",
			"Woodcraft"=>"SB2",
			"Language: Native"=>"60+SB1",
			"Script: Native"=>"70+SB1"
			},
     "Laborer/Longshoreman"=>{"urban"=>95,"years"=>1,
			"Intrigue"=>"SB4",
			"Seamanship"=>"SB2",
			"Language: Native"=>"60+SB1"
			},
     "Low Guard"=>{"urban"=>90,"years"=>4,
			"Initiative"=>"SB5",
			"Spear"=>"SB6",
			"Axe (Battleaxe)"=>"SB5",
			"Dagger (Dagger)"=>"SB5",
			"Shield (Round)"=>"SB5",
			"Foraging"=>"SB4",
			"Survival"=>"SB4",
			"Heraldry"=>"SB2",
			"Physician"=>"SB2",
			"Weaponcraft"=>"SB2"
			},
     "Mason"=>{"urban"=>60,"years"=>7,
			"Masonry"=>"SB4",
			"Woodcraft"=>"SB3",
			"Engineering"=>"SB3",
			"Mathematics"=>"SB2",
			"Language: Native"=>"60+SB1",
			"Script: Native"=>"70+SB1"
			},
     "Mercantyler"=>{"urban"=>90,"years"=>6,
			"Rhetoric"=>"SB5",
			"Intrigue"=>"SB5",
			"Mathematics"=>"SB3",
			"Law"=>"SB2",
			"Dagger"=>"SB3",
			"Language: Native"=>"60+SB1",
			"Language: Second"=>"60+SB1",
			"Script: Native"=>"70+SB1"
			},
     "Mercenary"=>{"urban"=>70,"years"=>4,
			"Initiative"=>"SB5",
			"Spear"=>"SB6",
			"Sword (Falchion)"=>"SB5",
			"Dagger (Dagger)"=>"SB5",
			"Shield (Round)"=>"SB5",
			"Foraging"=>"SB4",
			"Survival"=>"SB4",
			"Heraldry"=>"SB2",
			"Physician"=>"SB2",
			"Weaponcraft"=>"SB2"
			},
     "Metalsmith"=>{"urban"=>15,"years"=>6,
			"Metalcraft"=>"SB4",
			"Mining"=>"SB2",
			"Weaponcraft"=>"SB2",
			"Language: Native"=>"60+SB1"
			},
     "Miller"=>{"urban"=>10,"years"=>6,
			"Milling"=>"SB4",
			"Engineering"=>"SB3",
			"Agriculture"=>"SB3",
			"Language: Native"=>"60+SB1",
			"Script: Native"=>"70+SB1"
			},
     "Miner"=>{"urban"=>1,"years"=>6,
			"Mining"=>"SB4",
			"Engineering"=>"SB3",
			"Woodcraft"=>"SB2",
			"Metalcraft"=>"SB2",
			"Jewelcraft"=>"SB1",
			"Language: Native"=>"60+SB1"
			},
     "Ostler"=>{"urban"=>75,"years"=>5,
			"Animalcraft (Horse)"=>"SB4",
			"Riding"=>"SB4",
			"Hidework"=>"SB3",
			"Language: Native"=>"60+SB1"
			},
     "Patrician"=>{"urban"=>0,"years"=>7,
			"Riding"=>"SB6",
			"Initiative"=>"SB6",
			"Polearm (Lance)"=>"SB6",
			"Sword (Broadsword)"=>"SB5",
			"Axe (Handaxe)"=>"SB5",
			"Dagger (Dagger)"=>"SB5",
			"Shield (Kite)"=>"SB6",
			"Dancing"=>"SB3",
			"Law"=>"SB3",
			"Agriculture"=>"SB2",
			"Foraging"=>"SB4",
			"Survival"=>"SB4",
			"Heraldry"=>"SB2",
			"Physician"=>"SB2",
			"Weaponcraft"=>"SB2"
			},
     "Perfumer"=>{"urban"=>95,"years"=>6,
			"Perfumery"=>"SB4",
			"Alchemy"=>"SB3",
			"Herblore"=>"SB3",
			"Embalming"=>"SB2",
			"Language: Native"=>"60+SB1",
			"Script: Native"=>"70+SB1"
			},
     "Physician"=>{"urban"=>75,"years"=>7,
			"Physician"=>"SB4",
			"Herblore"=>"SB3",
			"Alchemy"=>"SB3",
			"Language: Native"=>"60+SB1",
			"Script: Native"=>"70+SB1"
			},
     "Pilot"=>{"urban"=>95,"years"=>9,
			"Piloting"=>"SB4",
			"Weatherlore"=>"SB4",
			"Seamanship"=>"SB3",
			"Drawing"=>"SB3",
			"Sword"=>"SB3",
			"Shipwright"=>"SB2",
			"Mathematics"=>"SB2",
			"Language: Native"=>"60+SB1",
			"Script: Native"=>"70+SB1"
			},
     "Pimp"=>{"urban"=>75,"years"=>1,
			"Lovecraft"=>"SB4",
			"Intrigue"=>"SB4",
			"Dagger"=>"SB4"
			},
     "Potter"=>{"urban"=>85,"years"=>6,
			"Ceramics"=>"SB4",
			"Glasswork"=>"SB2",
			"Language: Native"=>"60+SB1"
			},
     "Prostitute"=>{"urban"=>75,"years"=>1,
			"Lovecraft"=>"SB4",
			"Intrigue"=>"SB4",
			"Dagger"=>"SB4"
			},
     "Ranger"=>{"urban"=>0,"years"=>5,
			"Initiative"=>"SB5",
			"Bow (Hartbow)"=>"SB6",
			"Sword (Longknife)"=>"SB5",
			"Dagger (Dagger)"=>"SB5",
			"Shield (Buckler)"=>"SB5",
			"Foraging"=>"SB4",
			"Survival"=>"SB4",
			"Heraldry"=>"SB2",
			"Physician"=>"SB2",
			"Weaponcraft"=>"SB2"
			},
     "Ratter"=>{"urban"=>70,"years"=>3,
			"Animalcraft (Rat)"=>"SB5",
			"Animalcraft (Dog)"=>"SB4",
			"Net"=>"SB3",
			"Club"=>"SB5",
			"Herblore"=>"SB2"
			},
     "Sage/Tutor"=>{"urban"=>80,"years"=>5,
			"Folklore"=>"SB4",
			"Mathematics"=>"SB2",
			"Language: Native"=>"80+SB1",
			"Language: Second"=>"80+SB1",
			"Script: Native"=>"70+SB1",
			"Script: Second"=>"70+SB1"
			},
     "Salter"=>{"urban"=>30,"years"=>4,
			"Mining"=>"SB3",
			"Cookery"=>"SB4",
			"Survival"=>"SB3",
			"Fishing"=>"SB3",
			"Herblore"=>"SB1",
			"Language: Native"=>"60+SB1"
			},
     "Scribe"=>{"urban"=>90,"years"=>5,
			"Drawing"=>"SB3",
			"Mathematics"=>"SB2",
			"Language: Native"=>"80+SB1",
			"Language: Second"=>"80+SB1",
			"Script: Native"=>"70+SB1",
			"Script: Second"=>"70+SB1",
			"Script: Third"=>"70+SB1"
			},
     "Seaman"=>{"urban"=>95,"years"=>5,
			"Seamanship"=>"SB4",
			"Climbing"=>"SB5",
			"Club"=>"SB5",
			"Dagger"=>"SB4",
			"Fishing"=>"SB3",
			"Weatherlore"=>"SB3",
			"Piloting"=>"SB2",
			"Shipwright"=>"SB2",
			"Language: Native"=>"60+SB1"
			},
     "Shaman"=>{"urban"=>0,"years"=>7,
			"Ritual: Tribal"=>"SB4",
			"Folklore"=>"SB4",
			"Intrigue"=>"SB4",
			"Mental Conflict"=>"SB4",
			"Rhetoric"=>"SB4",
			"Dancing"=>"SB3",
			"Foraging"=>"SB3",
			"Oratory"=>"SB3",
			"Embalming"=>"SB2",
			"Physician"=>"SB2",
			"Weatherlore"=>"SB2"
			},
     "Shek-Pvar"=>{"urban"=>90,"years"=>7,
			"Convocation: Neutral"=>"SB2",
			"Folklore"=>"SB4",
			"Script: Native"=>"70+SB2",
			"Language: Native"=>"80+SB1",
			"Mathematics"=>"SB2"
			},
     "Package:Shek-Pvar:Lyahvi"=>{"urban"=>90,"years"=>7,
			"Convocation: Lyahvi"=>"SB3",
			"Legerdemain"=>"SB3",
			"Glasswork"=>"SB3",
			"Jewelcraft"=>"SB3"
			},
     "Package:Shek-Pvar:Peleahn"=>{"urban"=>90,"years"=>7,
			"Convocation: Peleahn"=>"SB3",
			"Alchemy"=>"SB3",
			"Cookery"=>"SB4",
			"Metalcraft"=>"SB1",
			"Weaponcraft"=>"SB1"
			},
     "Package:Shek-Pvar:Jmorvi"=>{"urban"=>90,"years"=>7,
			"Convocation: Jmorvi"=>"SB3",
			"Metalcraft"=>"SB3",
			"Lockcraft"=>"SB3",
			"Mining"=>"SB2",
			"Weaponcraft"=>"SB2"
			},
     "Package:Shek-Pvar:Fyvria"=>{"urban"=>90,"years"=>7,
			"Convocation: Fyvria"=>"SB3",
			"Herblore"=>"SB3",
			"Agriculture"=>"SB3",
			"Animalcraft"=>"SB2",
			"Embalming"=>"SB2",
			"Foraging"=>"SB3",
			"Physician"=>"SB2",
			"Survival"=>"SB3",
			"Tracking"=>"SB2"
			},
     "Package:Shek-Pvar:Odivshe"=>{"urban"=>90,"years"=>7,
			"Convocation: Odivshe"=>"SB3",
			"Swimming"=>"SB4",
			"Fishing"=>"SB3",
			"Piloting"=>"SB2",
			"Seamanship"=>"SB2",
			"Brewing"=>"SB2"
			},
     "Package:Shek-Pvar:Savorya"=>{"urban"=>90,"years"=>7,
			"Convocation: Savorya"=>"SB3",
			"Mental Conflict"=>"SB5",
			"Drawing"=>"SB4",
			"Runecraft"=>"SB3",
			"Tarotry"=>"SB3"
			},
     "Shipwright"=>{"urban"=>90,"years"=>7,
			"Shipwright"=>"SB4",
			"Woodcraft"=>"SB3",
			"Timbercraft"=>"SB3",
			"Metalcraft"=>"SB2",
			"Mathematics"=>"SB2",
			"Seamanship"=>"SB2",
			"Language: Native"=>"60+SB1",
			"Script: Native"=>"70+SB1"
			},
     "Teamster"=>{"urban"=>90,"years"=>2,
			"Riding"=>"SB4",
			"Animalcraft"=>"SB3",
			"Whip"=>"SB3",
			"Woodcraft"=>"SB2"
			},
     "Tentmaker"=>{"urban"=>95,"years"=>5,
			"Textilecraft"=>"SB3",
			"Hidework"=>"SB3",
			"Woodcraft"=>"SB2",
			"Language: Native"=>"60+SB1"
			},
     "Thatcher"=>{"urban"=>5,"years"=>4,
			"Climbing"=>"SB5",
			"Woodcraft"=>"SB3",
			"Engineering"=>"SB2"
			},
     "Thespian"=>{"urban"=>70,"years"=>7,
			"Acting"=>"SB4",
			"Oratory"=>"SB4",
			"Singing"=>"SB4",
			"Musician: First"=>"SB3",
			"Drawing"=>"SB3",
			"Language: Native"=>"60+SB1"
			},
     "Thief (Lia-Kavair)"=>{"urban"=>75,"years"=>3,
			"Legerdemain"=>"SB4",
			"Awareness"=>"SB5",
			"Stealth"=>"SB4",
			"Intrigue"=>"SB4",
			"Lockcraft"=>"SB3",
			"Club"=>"SB5",
			"Dagger"=>"SB4",
			"Acrobatics"=>"SB2"
			},
     "Timberwright"=>{"urban"=>10,"years"=>6,
			"Timbercraft"=>"SB4",
			"Survival"=>"SB3",
			"Weatherlore"=>"SB4",
			"Woodcraft"=>"SB3",
			"Language: Native"=>"60+SB1"
			},
     "Toymaker"=>{"urban"=>75,"years"=>5,
			"Woodcraft"=>"SB4",
			"Lockcraft"=>"SB3",
			"Drawing"=>"SB3",
			"Hidework"=>"SB2"
			},
     "Weaponcrafter"=>{"urban"=>75,"years"=>7,
			"Weaponcraft"=>"SB4",
			"Sword"=>"SB3",
			"Bow"=>"SB2",
			"Metalcraft"=>"SB3",
			"Fletching"=>"SB3",
			"Mining"=>"SB2",
			"Language: Native"=>"60+SB1"
			},
     "Woodcrafter"=>{"urban"=>30,"years"=>7,
			"Woodcraft"=>"SB5",
			"Metalcraft"=>"SB2",
			"Hidework"=>"SB2",
			"Language: Native"=>"60+SB1"
			},
     "Yeoman"=>{"urban"=>0,"years"=>4,
			"Initiative"=>"SB5",
			"Bow (Longbow)"=>"SB5",
			"Sword (Falchion)"=>"SB5",
			"Dagger (Dagger)"=>"SB5",
			"Shield (Buckler)"=>"SB5",
			"Foraging"=>"SB4",
			"Survival"=>"SB4",
			"Heraldry"=>"SB2",
			"Physician"=>"SB2",
			"Weaponcraft"=>"SB2"
			}
     );

######################################################################
my %occupationroll = 
    ("Tribal::Slave"=>
     {20=>"Farmer",
      80=>"Herdsman",
      200=>"Cook/Servant"
      },
     "Tribal::Serf"=>
     {200=>"None"
      },
     "Tribal::Unguilded"=>
     {3=>"Shaman",
      20=>"Fisherman",
      40=>"Herdsman",
      200=>"Hunter/Trapper"
      },
     "Tribal::Guilded"=>
     {200=>"None"
      },
     "Tribal::Noble"=>
     {
	200=>"Chieftain"
      },
     "Viking::Slave"=>
     {80=>"Farmer",
      97=>"Herdsman",
      200=>"Cook/Servant"
      },
     "Viking::Serf"=>
     {80=>"Farmer",
      95=>"Herdsman",
      200=>"Cook/Servant"
      },
     "Viking::Unguilded"=>
     {1=>"Animal Trainer",
      3=>"Beggar",
      4=>"Cartographer/Artist",
      6=>"Cleric",
      10=>"Cook/Servant",
      55=>"Farmer",
      65=>"Fisherman",
      70=>"Herdsman",
      76=>"Hunter/Trapper",
      83=>"Laborer/Longshoreman",
      85=>"Pimp|Prostitute",
      87=>"Ratter",
      88=>"Sage/Tutor",
      90=>"Scribe",
      91=>"Clansman",
      97=>"Huscarl",
      98=>"Teamster",
      99=>"Thatcher",
      200=>"Toymaker"
      },
     "Viking::Guilded"=>
     {1=>"Alchemist",
      2=>"Apothecary",
      3=>"Astrologer",
      5=>"Chandler",
      8=>"Charcoaler",
      11=>"Clothier",
      12=>"Clothier|Courtesan",
      14=>"Embalmer",
      16=>"Glassworker",
      21=>"Harper/Skald",
      27=>"Hideworker",
      31=>"Innkeeper",
      33=>"Jeweler",
      35=>"Lexigrapher",
      36=>"Litigant",
      37=>"Locksmith",
      38=>"Shek-Pvar",
      40=>"Mason",
      48=>"Mercantyler",
      57=>"Metalsmith",
      64=>"Miller",
      67=>"Miner",
      68=>"Ostler",
      70=>"Perfumer",
      71=>"Physician",
      73=>"Pilot",
      77=>"Potter",
      79=>"Salter",
      83=>"Seaman",
      84=>"Shipwright",
      85=>"Tentmaker",
      86=>"Thespian",
      88=>"Thief (Lia-Kavair)",
      90=>"Timberwright",
      92=>"Weaponcrafter",
      200=>"Woodcrafter"
      },
     "Viking::Noble"=>
     {3=>"Herald",
      200=>"Knight|Lady"
      },
     "Feudal::Slave"=>
     {80=>"Farmer",
      95=>"Herdsman",
      200=>"Cook/Servant"
      },
     "Feudal::Serf"=>
     {80=>"Farmer",
      95=>"Herdsman",
      200=>"Cook/Servant"
      },
     "Feudal::Unguilded"=>
     {0=>"Archer",
      2=>"Animal Trainer",
      5=>"Beggar",
      6=>"Cartographer/Artist",
      8=>"Cleric",
      12=>"Cook/Servant",
      60=>"Farmer",
      66=>"Fisherman",
      67=>"Gladiator",
      69=>"Herdsman",
      72=>"Hunter/Trapper",
      80=>"Laborer/Longshoreman",
      82=>"Pimp|Prostitute",
      84=>"Ratter",
      85=>"Sage/Tutor",
      87=>"Scribe",
      88=>"Guardsman",
      90=>"Mercenary",
      97=>"Yeoman",
      98=>"Teamster",
      99=>"Thatcher",
      200=>"Toymaker"
      },
     "Feudal::Guilded"=>
     {1=>"Alchemist",
      2=>"Apothecary",
      3=>"Astrologer",
      5=>"Chandler",
      7=>"Charcoaler",
      11=>"Clothier",
      12=>"Clothier|Courtesan",
      14=>"Embalmer",
      16=>"Glassworker",
      19=>"Harper/Skald",
      26=>"Hideworker",
      31=>"Innkeeper",
      33=>"Jeweler",
      35=>"Lexigrapher",
      36=>"Litigant",
      37=>"Locksmith",
      38=>"Shek-Pvar",
      41=>"Mason",
      47=>"Mercantyler",
      56=>"Metalsmith",
      64=>"Miller",
      67=>"Miner",
      69=>"Ostler",
      71=>"Perfumer",
      72=>"Physician",
      73=>"Pilot",
      77=>"Potter",
      79=>"Salter",
      82=>"Seaman",
      83=>"Shipwright",
      84=>"Tentmaker",
      85=>"Thespian",
      88=>"Thief (Lia-Kavair)",
      90=>"Timberwright",
      92=>"Weaponcrafter",
      200=>"Woodcrafter"
      },
     "Feudal::Noble"=>
     {5=>"Cleric",
      10=>"Herald",
      15=>"Bailiff",
      85=>"Knight Bachelor|Lady",
      200=>"Knight|Lady"
      },
     "Imperial::Slave"=>
     {75=>"Farmer",
      90=>"Herdsman",
      98=>"Cook/Servant",
      200=>"Gladiator"
      },
     "Imperial::Serf"=>
     {200=>"None"
      },
     "Imperial::Unguilded"=>
     {2=>"Animal Trainer",
      6=>"Beggar",
      7=>"Cartographer/Artist",
      9=>"Cleric",
      13=>"Cook/Servant",
      38=>"Farmer",
      44=>"Fisherman",
      47=>"Gladiator",
      54=>"Herdsman",
      57=>"Hunter/Trapper",
      65=>"Laborer/Longshoreman",
      69=>"Pimp|Prostitute",
      71=>"Ratter",
      75=>"Sage/Tutor",
      80=>"Scribe",
      90=>"Legionnaire",
      95=>"Mercenary",
      97=>"Teamster",
      98=>"Thatcher",
      200=>"Toymaker"
      },
     "Imperial::Guilded"=>
     {1=>"Alchemist",
      2=>"Apothecary",
      3=>"Astrologer",
      5=>"Chandler",
      7=>"Charcoaler",
      10=>"Clothier",
      11=>"Clothier|Courtesan",
      13=>"Embalmer",
      15=>"Glassworker",
      18=>"Harper/Skald",
      24=>"Hideworker",
      28=>"Innkeeper",
      30=>"Jeweler",
      32=>"Lexigrapher",
      33=>"Litigant",
      34=>"Locksmith",
      36=>"Shek-Pvar",
      39=>"Mason",
      45=>"Mercantyler",
      54=>"Metalsmith",
      62=>"Miller",
      65=>"Miner",
      68=>"Ostler",
      71=>"Perfumer",
      72=>"Physician",
      73=>"Pilot",
      77=>"Potter",
      79=>"Salter",
      82=>"Seaman",
      83=>"Shipwright",
      84=>"Tentmaker",
      85=>"Thespian",
      88=>"Thief (Lia-Kavair)",
      90=>"Timberwright",
      92=>"Weaponcrafter",
      200=>"Woodcrafter"
      },
     "Imperial::Noble"=>
     {5=>"Cleric",
      10=>"Herald",
      38=>"Bailiff",
      200=>"Patrician|Lady"
      },
     "Sindarin::Slave"=>
     {200=>"None"
      },
     "Sindarin::Serf"=>
     {200=>"None"
      },
     "Sindarin::Unguilded"=>
     {0=>"Horsebow",
      1=>"Animal Trainer",
      3=>"Cartographer/Artist",
      4=>"Cleric",
      8=>"Cook/Servant",
      19=>"Fisherman",
      57=>"Hunter/Trapper",
      64=>"Scribe",
      74=>"Ranger",
      95=>"Guardian",
      96=>"Teamster",
      97=>"Thatcher",
      200=>"Toymaker"
      },
     "Sindarin::Guilded"=>
     {2=>"Alchemist",
      4=>"Apothecary",
      5=>"Astrologer",
      6=>"Chandler",
      7=>"Charcoaler",
      12=>"Clothier",
      13=>"Embalmer",
      25=>"Glassworker",
      35=>"Harper/Skald",
      45=>"Hideworker",
      49=>"Innkeeper",
      58=>"Jeweler",
      62=>"Lexigrapher",
      63=>"Locksmith",
      68=>"Shek-Pvar",
      74=>"Mason",
      76=>"Mercantyler",
      80=>"Metalsmith",
      81=>"Miller",
      82=>"Miner",
      83=>"Ostler",
      84=>"Perfumer",
      85=>"Physician",
      86=>"Pilot",
      87=>"Potter",
      88=>"Salter",
      89=>"Seaman",
      90=>"Shipwright",
      91=>"Tentmaker",
      92=>"Thespian",
      93=>"Thief (Lia-Kavair)",
      94=>"Timberwright",
      96=>"Weaponcrafter",
      200=>"Woodcrafter"
      },
     "Sindarin::Noble"=>
     {3=>"Herald",
      200=>"Knight|Lady"
      },
     "Khuzan::Slave"=>
     {200=>"None"
      },
     "Khuzan::Serf"=>
     {200=>"None"
      },
     "Khuzan::Unguilded"=>
     {1=>"Animal Trainer",
      3=>"Cartographer/Artist",
      4=>"Cleric",
      19=>"Cook/Servant",
      21=>"Hunter/Trapper",
      33=>"Laborer/Longshoreman",
      57=>"Sage/Tutor",
      64=>"Scribe",
      74=>"Low Guard",
      98=>"Teamster",
      200=>"Toymaker"
      },
     "Khuzan::Guilded"=>
     {1=>"Alchemist",
      2=>"Apothecary",
      3=>"Astrologer",
      6=>"Chandler",
      7=>"Charcoaler",
      11=>"Clothier",
      12=>"Embalmer",
      13=>"Glassworker",
      17=>"Harper/Skald",
      18=>"Hideworker",
      20=>"Innkeeper",
      30=>"Jeweler",
      33=>"Lexigrapher",
      34=>"Litigant",
      36=>"Locksmith",
      37=>"Shek-Pvar",
      47=>"Mason",
      60=>"Mercantyler",
      68=>"Metalsmith",
      69=>"Miller",
      84=>"Miner",
      85=>"Perfumer",
      86=>"Physician",
      87=>"Potter",
      88=>"Salter",
      89=>"Tentmaker",
      90=>"Thespian",
      91=>"Thief (Lia-Kavair)",
      92=>"Timberwright",
      99=>"Weaponcrafter",
      200=>"Woodcrafter"
      },
     "Khuzan::Noble"=>
     {2=>"Herald",
      85=>"High Guard|Lady",
      200=>"Knight|Lady"
      }
     );

######################################################################
### Here we are going to sort and error check the skill list. 
my %def_of_skill;
my %skilltypes;
foreach my $ref (@skilldefs) {
    my $name = $ref->{"name"};
    foreach my $key (keys %$ref) {
	my $data = $ref->{$key};
	if ($key eq "name") {
	} elsif ($key eq "type") {
	    $data =~ m!^(Combat|Communication|Convocation|Craft/Lore|Language|Physical|Religion|Script|Talent)$! or die "Bad $key '$data' in $name";
	} elsif ($key eq "sb") {
	    $data =~ m/^([A-Z]{3}) ([A-Z]{3}) ([A-Z]{3})$/ or 
		die "Invalid $key '$data' in $name";
	} elsif ($key eq "signs") {
	    $data =~ m!^(none|\w\w\w(/|[\+\-]\d;?))*$! or 
		die "Invalid $key '$data' in $name";
	} elsif ($key eq "oml") {
	    $data =~ m/^(\d\d?\+)?(SB\d)?$/ or 
		die "Invalid $key '$data' in $name";
	} else {
	    die "Invalid key '$key'";
	}
    }
    $def_of_skill{$name} = $ref;
    $skilltypes{ $ref->{"type"} }++;
}
######################################################################
### Now error check the occupation hash
foreach my $occname (keys %occupationhash) {
    my $ref = $occupationhash{$occname};
    foreach my $key (keys %$ref) {
	my $data = $ref->{$key};
	if ($key =~ m/^(urban|years)$/) {
	    die "Bad $key '$data' in $occname" unless ($data =~ m/^\d\d?$/);
	} else {
	    $key =~ s/\s*\(.*?\)//; # remove parenthetical specialization
	    die "Bad key $key in $occname" unless ($def_of_skill{$key});
	    die "Bad base $data for $key in $occname" unless 
		($data =~ m/^(\d\d?\+)?(SB\d)?$/);
	}
    }
}
######################################################################
### Finally error check the 
my %occ_cultures;
my %occ_classes;
foreach my $column (keys %occupationroll) {
    $column =~ m/^(\w+)::(\w+)$/ or die "Invalid occupation roll column '$column'";
    my ($culture,$class) = ($1,$2);
    $occ_cultures{$culture}++;
    $occ_classes{$class}++;
    my $ref = $occupationroll{$column};
    foreach my $n (sort {$a<=>$b} keys %$ref) {
	$n =~ m/^\d{1,3}$/ or 
	    die "Invalid key '$n' in occupation roll column '$column'";
	my $occname = $ref->{$n};
	if ($occname =~ m/(.*)\|(.*)/) {
	    my ($occmale,$occfemale) = ($1,$2);
	    die "Invalid name '$occmale' in occupation roll column '$column'"
		unless defined($occupationhash{$occmale});
	    die "Invalid name '$occfemale' in occupation roll column '$column'"
		unless defined($occupationhash{$occfemale});
	} else {
	    die "Invalid name '$occname' in occupation roll column '$column'"
		unless defined($occupationhash{$occname});
	}
    }
}
foreach my $culture (keys %occ_cultures) {
    foreach my $class (keys %occ_classes) {
	if (not $occupationroll{$culture."::".$class}) {
	    warn "Missing occupation roll for culture '$culture' and social class '$class'";
	}
    }
}
######################################################################
=item new (Constructor)
Create a new instance of this class by writing
    $data = HM3Data->new();
=cut
sub new { 
    my $that = shift;  # either class name or template object
    my $self = {};     # $self is a hash reference
    bless($self, $that);
    return $self;
}
######################################################################
=item isDefinedSkill

=cut
sub isDefinedSkill {
    my ($self,$name) = @_;
    $name =~ s/\s*\(.*?\)//; # remove parenthetical specialization
    return defined($def_of_skill{$name});
}
######################################################################
=item getSkillType
Given a skill name, returns the type name for that skill
=cut
sub getSkillType {
    my ($self,$name) = @_;
    croak "Invalid skill '$name'" unless ($self->isDefinedSkill($name));
    return $def_of_skill{$name}->{"type"};
}
######################################################################
=item getSkillTypeList
Returns an array of all defined skill types
=cut
sub getSkillTypeList {
    return keys %skilltypes;
}
######################################################################
=item getSkillBaseCode
Given a skill name, returns the code for the skill base, 
in format like "AUR WIL WIL". 
=cut
sub getSkillBaseCode {
    my ($self,$name) = @_;
    croak "Invalid skill '$name'" unless ($self->isDefinedSkill($name));
    return $def_of_skill{$name}->{"sb"};
}
######################################################################
=item getSkillSignCode
Given a skill name, returns the code for the sunsign bonus, 
in format like "Tai+3;Tar/Sko+2"
=cut
sub getSkillSignCode {
    my ($self,$name) = @_;
    croak "Invalid skill '$name'" unless ($self->isDefinedSkill($name));
    return $def_of_skill{$name}->{"signs"};
}
######################################################################
=item getSkillOMLCode
Given a skill name, returns the code for the starting OML, 
in format like "SB4" or "70+SB1"
=cut
sub getSkillOMLCode {
    my ($self,$name) = @_;
    croak "Invalid skill '$name'" unless ($self->isDefinedSkill($name));
    return $def_of_skill{$name}->{"oml"};
}
######################################################################
=item getOccupationList
Returns a sorted list of all occupation names.  
=cut
sub getOccupationList {
    return sort keys %occupationhash;
}
######################################################################
=item getOccupationUrbanChance
Given an occupation name, returns the urban percentage chance. 
=cut
sub getOccupationUrbanChance {
    my ($self,$occname) = @_;
    my $ref = $occupationhash{$occname} or croak "Invalid occupation '$occname'";
    return $ref->{"urban"};
}
######################################################################
=item getOccupationYears
Given an occupation name, returns the years stat.
=cut
sub getOccupationYears {
    my ($self,$occname) = @_;
    my $ref = $occupationhash{$occname} or croak "Invalid occupation '$occname'";
    return $ref->{"years"};
}
######################################################################
=item getOccupationSkills
Given an occupation name, returns an array of the skills it has.
=cut
sub getOccupationSkills {
    my ($self,$occname) = @_;
    my $ref = $occupationhash{$occname} or croak "Invalid occupation '$occname'";
    return grep { not m/^(urban|years)$/ } keys %$ref;
}
######################################################################
=item getOccupationSkillCode
Given an occupation name and skill name, returns the starting value 
in format like "SB4" or "70+SB1"
=cut
sub getOccupationSkillCode {
    my ($self,$occname,$skillname) = @_;
    my $ref = $occupationhash{$occname} or croak "Invalid occupation '$occname'";
    return $ref->{$skillname};
}
######################################################################
=item getOccupationRolls
Given a culture name and social class name, returns an array of 
the break point percentages in the roll for occupation.  
=cut
sub getOccupationRolls {
    my ($self,$culture,$socialclass) = @_;
    my $column = "$culture::$socialclass";
    my $ref = $occupationroll{$column} or 
	croak "Invalid culture and social class '$column'";
    return sort {$a<=>$b} keys %$ref;
}
######################################################################
=item getOccupationResult
Given a culture name, social class name, and a roll number, 
this gives the resulting occupation.  
=cut
sub getOccupationResult {
    my ($self,$culture,$socialclass,$roll) = @_;
    croak "Invalid roll '$roll'" unless ($roll =~ m/^\d{1,3}$/);
    my $column = $culture."::".$socialclass;
    my $ref = $occupationroll{$column} or 
	croak "Invalid culture and social class '$column'";
    foreach my $n (sort {$a<=>$b} keys %$ref) {
	return $ref->{$n} if ($roll <= $n);
    }
}

1; # required end-of-module line

